==> foundation-ui-components-1.11.0.tgz: package/src/common/dropdown/stories/NsDropdown.stories.tsx <==
import React, { useState } from 'react';
import type { Meta, StoryObj } from '@storybook/react';
import { NsDropdown, NsDropdownOption } from '../';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';

type ComponentType = typeof NsDropdown;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Inputs/NsDropdown',
    decorators: [withCenterDecorator],
    component: NsDropdown,
    argTypes: {
        type: { control: 'select', options: ['unfilled', 'outlined'] },
        disabled: { control: 'boolean' },
        dropdownBorderColor: {
            control: 'select',
            options: ['primary', 'secondary', 'accentColorA', 'accentColorB', 'accentColorC'],
        },
        placeholder: { control: 'text' },
        closeOnMouseLeave: { control: 'boolean' },
        showListDivider: { control: 'boolean' },
    },
    parameters: {
        options: [
            { label: 'Option 1', value: 'Option 1' },
            { label: 'Option 2', value: 'Option 2' },
            { label: 'Option 3', value: 'Option 3' },
        ],
    },
    args: {
        type: 'outlined',
        disabled: false,
        dropdownBorderColor: 'primary',
        closeOnMouseLeave: false,
        showListDivider: true,
        selectedValue: '',
        selectedLabel: '',
    },
} as MetaStory;

const RenderStory = (args: any, context: any) => {
    const [selectedLabel, setSelectedLabel] = useState(args.selectedLabel);
    const [selectedValue, setSelectedValue] = useState(args.selectedValue);

    const options = context.parameters.options;
    const handleSelect = (value: string) => {
        setSelectedValue(value);
        options.find((option: any) => {
            if (option.value === value) {
                setSelectedLabel(option.label);
            }
        });
    };

    return (
        <NsDropdown {...args} selectedValue={selectedValue} selectedLabel={selectedLabel} onSelect={handleSelect}>
            {options.map((option: any) => (
                <NsDropdownOption key={option.value} value={option.value} label={option.label} />
            ))}
        </NsDropdown>
    );
};
export const Dropdown: Story = {
    render: RenderStory,
};

==> foundation-ui-components-1.26.1.tgz: package/src/common/dropdown/stories/NsDropdown.stories.tsx <==
import React, { useState } from 'react';
import type { Meta, StoryObj } from '@storybook/react';
import { NsDropdown, NsDropdownOption } from '../';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';

type ComponentType = typeof NsDropdown;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Inputs/NsDropdown',
    decorators: [withCenterDecorator],
    component: NsDropdown,
    argTypes: {
        type: { control: 'select', options: ['unfilled', 'outlined'] },
        disabled: { control: 'boolean' },
        dropdownBorderColor: {
            control: 'select',
            options: ['primary', 'secondary', 'accentColorA', 'accentColorB', 'accentColorC'],
        },
        placeholder: { control: 'text' },
        closeOnMouseLeave: { control: 'boolean' },
    },
    parameters: {
        options: [
            { label: 'Option 1', value: 'Option 1' },
            { label: 'Option 2', value: 'Option 2' },
            { label: 'Option 3', value: 'Option 3' },
        ],
    },
    args: {
        type: 'outlined',
        disabled: false,
        dropdownBorderColor: 'primary',
        closeOnMouseLeave: false,
        selectedLabel: '',
        placeholder: 'options',
    },
} as MetaStory;

const RenderStory = (args: any, context: any) => {
    const [selectedLabel, setSelectedLabel] = useState(args.selectedLabel);

    const options = context.parameters.options;
    const handleSelect = (value: string) => {
        options.find((option: any) => {
            if (option.value === value) {
                setSelectedLabel(option.label);
            }
        });
    };

    return (
        <NsDropdown {...args} selectedLabel={selectedLabel} onSelect={handleSelect}>
            {options.map((option: any) => (
                <NsDropdownOption key={option.value} value={option.value}>
                    {option.label}
                </NsDropdownOption>
            ))}
        </NsDropdown>
    );
};
export const Dropdown: Story = {
    render: RenderStory,
};
